"
COPYRIGHT (c) 1997 by eXept Software AG / Claus Gittinger
	      All Rights Reserved

 This software is furnished under a license and may be used
 only in accordance with the terms of that license and with the
 inclusion of the above copyright notice.   This software may not
 be provided or otherwise made available to, or used by, any
 other person.  No title to or ownership of the software is
 hereby transferred.
"



'From Smalltalk/X, Version:4.1.4 on 20-Mai-2002 at 15:13:09'                    !

"{ Package: 'stx:libview' }"

GraphicsDevice subclass:#HostGraphicsDevice
	instanceVariableNames:'deviceColors deviceFonts deviceViews deviceForms deviceCursors'
	classVariableNames:''
	poolDictionaries:''
	category:'Interface-Graphics'
!

!HostGraphicsDevice class methodsFor:'documentation'!

copyright
"
COPYRIGHT (c) 1997 by eXept Software AG / Claus Gittinger
	      All Rights Reserved

 This software is furnished under a license and may be used
 only in accordance with the terms of that license and with the
 inclusion of the above copyright notice.   This software may not
 be provided or otherwise made available to, or used by, any
 other person.  No title to or ownership of the software is
 hereby transferred.
"


!

documentation
"
    this abstract class was inserted to provide a home for ST-80 classes
    (previously, DeviceWorkstation was directly under Object).
    We will (over time) move common functionality from there into this class.

    In ST/X, this is mostly dummy.

    [see also:]
	DeviceWorkstation XWorkstation

    [author:]
	Claus Gittinger
"


! !

!HostGraphicsDevice class methodsFor:'instance creation'!

newDispatchingFor:aScreenName
    "create a new instance of mySelf, which serves aDeviceName.
     Only useful for device-classes which support multiple devices -
     i.e. X-Workstations"

    |newDevice someScreen|

    newDevice := self newFor:aScreenName.
    newDevice startDispatch.
    (someScreen := Screen current) isNil ifTrue:[
        someScreen := Screen default.
    ].
    someScreen notNil ifTrue:[
        newDevice keyboardMap:(someScreen keyboardMap).
        newDevice buttonTranslation:(someScreen buttonTranslation).
    ].

    "/ arrange for it to finish its event dispatch loop, 
    "/ when the last view on it is closed.
    newDevice exitOnLastClose:true.

    ^ newDevice.
! !

!HostGraphicsDevice methodsFor:'Compatibility - Squeak'!

deferUpdates: aBoolean
    "Set the deferUpdates flag in the virtual machine. 
     When this flag is true, BitBlt operations on the Display are not 
     automatically propagated to the screen. 
     If this underlying platform does not support deferred updates, 
     this primitive will fail. 
     Answer the receiver if the primitive succeeds, nil if it fails."

"/    <primitive: 126>
    ^ nil  "answer nil if primitive fails"

!

forceDisplayUpdate
    "On platforms that buffer screen updates, 
     force the screen to be updated immediately. 
     On other platforms, or if the primitive is not implemented, do nothing."

"/     <primitive: 231>
    "do nothing if primitive fails"
! !

!HostGraphicsDevice methodsFor:'accessing'!

deviceColors
    "return the registry keeping track of colors which were allocated
     on this device."

    ^ deviceColors

    "Created: 24.2.1997 / 18:01:41 / cg"
!

deviceCursors
    "return the registry keeping track of cursors which were allocated
     on this device."

    ^ deviceCursors

    "Created: 24.2.1997 / 18:01:41 / cg"
!

deviceFonts
    "return the registry keeping track of fonts which were allocated
     on this device."

    ^ deviceFonts
!

deviceForms
    "return the registry keeping track of forms which were allocated
     on this device."

    ^ deviceForms
!

deviceViews
    "return the registry keeping track of views which were allocated
     on this device."

    ^ deviceViews
! !

!HostGraphicsDevice methodsFor:'accessing & queries'!

defaultExtentForTopViews
    |w h|

    w := self width.
    h := self height.

    self isPDA ifTrue:[
        ^ (w - 16) @ (h - 20)
    ].
    ^ (w // 3 * 2) @ (h // 3 * 2)
! !

!HostGraphicsDevice methodsFor:'initialize / release'!

initializeDeviceResourceTables
    deviceViews := Registry new.
    deviceForms := Registry new.
    deviceColors := Registry new.
    deviceCursors := Registry new.
    deviceFonts := CachingRegistry new cacheSize:10.

    "Created: 24.2.1997 / 18:29:53 / cg"
!

releaseDeviceColors
    deviceColors do:[:aColor |
        aColor releaseFromDevice
    ].
    deviceColors := Registry new.

    "Created: 24.2.1997 / 18:07:49 / cg"

!

releaseDeviceCursors
    deviceCursors do:[:aCursor |
        aCursor releaseFromDevice
    ].
    deviceCursors := Registry new.

    "Created: 24.2.1997 / 18:07:49 / cg"

!

releaseDeviceFonts
    deviceFonts do:[:aFont |
        aFont releaseFromDevice.
    ].
    deviceFonts := CachingRegistry new cacheSize:10.
! !

!HostGraphicsDevice methodsFor:'misc'!

recolorCursorsToFgColor:fgColor defaultBgColor:bgColor
    "change the colors of all existing cursors"

    "/ recolor existing cursors
    deviceCursors do:[:eachCursor | eachCursor foreground:fgColor background:bgColor].

    "
     Display recolorCursorsToFgColor:(Color red) defaultBgColor:(Color white)

     Display recolorCursorsToFgColor:(Color blue) defaultBgColor:(Color white)
     Display recolorCursorsToFgColor:(Color blue) defaultBgColor:(Color black)
     Display recolorCursorsToFgColor:(Color white) defaultBgColor:(Color black)
     Display recolorCursorsToFgColor:(Color white) defaultBgColor:(Color red)
    "
! !

!HostGraphicsDevice methodsFor:'registration'!

registerColor:aColor
    deviceColors register:aColor.

    "Created: 24.2.1997 / 18:29:10 / cg"
!

registerCursor:aCursor
    deviceCursors register:aCursor.

    "Created: 24.2.1997 / 18:29:10 / cg"
!

registerFont:aFont
    deviceFonts register:aFont.

    "Created: 24.2.1997 / 18:29:10 / cg"
!

registerForm:aForm
    deviceForms register:aForm.

    "Created: 24.2.1997 / 18:29:10 / cg"
!

registerView:aView
    deviceViews register:aView.

    "Created: 24.2.1997 / 18:29:10 / cg"
!

unregisterColor:aColor
    deviceColors unregister:aColor.

    "Created: 24.2.1997 / 18:29:14 / cg"
!

unregisterCursor:aCursor
    deviceCursors unregister:aCursor.

    "Created: 24.2.1997 / 18:29:14 / cg"
!

unregisterFont:aFont
    deviceFonts unregister:aFont.

    "Created: 24.2.1997 / 18:29:14 / cg"
!

unregisterForm:aForm
    deviceForms unregister:aForm.

    "Created: 24.2.1997 / 18:29:14 / cg"
!

unregisterView:aView
    deviceViews unregister:aView.

    "Created: 24.2.1997 / 18:29:14 / cg"
! !

!HostGraphicsDevice class methodsFor:'documentation'!

version
    ^ '$Header: /cvs/stx/stx/libview/HostGraphicsDevice.st,v 1.19 2002-05-21 08:09:26 stefan Exp $'
! !
